tree 38f7a290fcca12bb13c7af19c5dafb99ca3bcaaa
parent 4e38d36d88ead4e56f3155573976da84d5df18b3
author Hal Rosenstock <[EMAIL PROTECTED]> Fri, 29 Jul 2005 03:17:26 -0700
committer Roland Dreier <[EMAIL PROTECTED]> Fri, 29 Jul 2005 03:17:26 -0700

[PATCH] [IPoIB] Handle sending of unicast RARP responses

RARP replies are another valid case where IPoIB may need to send a
unicast packet with no neighbour structure.

Signed-off-by: Hal Rosenstock <[EMAIL PROTECTED]>
Signed-off-by: Roland Dreier <[EMAIL PROTECTED]>

 drivers/infiniband/ulp/ipoib/ipoib_main.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/drivers/infiniband/ulp/ipoib/ipoib_main.c 
b/drivers/infiniband/ulp/ipoib/ipoib_main.c
--- a/drivers/infiniband/ulp/ipoib/ipoib_main.c
+++ b/drivers/infiniband/ulp/ipoib/ipoib_main.c
@@ -600,9 +600,10 @@ static int ipoib_start_xmit(struct sk_bu
 
                        ipoib_mcast_send(dev, (union ib_gid *) (phdr->hwaddr + 
4), skb);
                } else {
                        /* unicast GID -- should be ARP reply */
 
-                       if (be16_to_cpup((u16 *) skb->data) != ETH_P_ARP) {
+                       if ((be16_to_cpup((__be16 *) skb->data) != ETH_P_ARP) &&
+                           (be16_to_cpup((__be16 *) skb->data) != ETH_P_RARP)) 
{
                                ipoib_warn(priv, "Unicast, no %s: type %04x, 
QPN %06x "
                                           IPOIB_GID_FMT "\n",
                                           skb->dst ? "neigh" : "dst",
-
@@ -600,9 +600,10 @@ static int ipoib_start_xmit(struct sk_bu
4), skb);
                } else {
-                       /* unicast GID -- should be ARP reply */
+                       /* unicast GID -- should be ARP or RARP reply */
 
To unsubscribe from this list: send the line "unsubscribe bk-commits-head" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to